var assert = require('assert')

var ok = require('okay')

var Queue = require('../')
var helper = require('./helper')

var queuePrefix = helper.queuePrefix
var getName = helper.getName


describe('CRUD', function() {
  it('creates a queue', function(done) {
    var queueName = getName()
    Queue.create(queueName, {}, ok(done, function(queue) {
      assert(queue)
      assert(queue instanceof Queue, 'should be instance of queue')
      assert.equal(queue.name, queueName)
      assert(queue.url)
      done()
    }))
  })

  it('creates a queue without options', function(done) {
    var name = getName()
    Queue.create(name, ok(done, function(queue) {
      assert.equal(queue.name, name)
      done()
    }))
  })

  it('lists queues with prefix', function(done) {
    Queue.list(queuePrefix, ok(done, function(res) {
      assert(res.length >= 1, 'should have at least one queue')
      res.forEach(function(url) {
        assert(url.indexOf(queuePrefix) > -1)
      })
      done()
    }))
  })

  it('deletes all queues with prefix', function(done) {
    this.timeout(5000)
    Queue.destroyAll(queuePrefix, ok(done, function(res) {
      done()
    }))
  })
})
